@@ -5,6 +5,7 @@ import typeguard
 
 from cloud_governance.common.clouds.aws.utils.utils import Utils
 from cloud_governance.common.logger.logger_time_stamp import logger_time_stamp
+from cloud_governance.main.environment_variables import environment_variables
 
 
 class EC2Operations:
@@ -16,6 +17,7 @@ class EC2Operations:
         """
         Initializing the AWS resources
         """
+        self.__environment_variables_dict = environment_variables.environment_variables_dict
         self.elb1_client = boto3.client('elb', region_name=region)
         self.elbv2_client = boto3.client('elbv2', region_name=region)
         self.ec2_client = boto3.client('ec2', region_name=region)
@@ -318,21 +320,21 @@ class EC2Operations:
                 non_cluster.append(resource)
         return [cluster, non_cluster]
 
-    def get_instances(self):
+    def get_instances(self, **kwargs):
         """
         This method returns all instances from the region
         @return:
         """
         return self.utils.get_details_resource_list(func_name=self.ec2_client.describe_instances,
-                                                    input_tag='Reservations', check_tag='NextToken')
+                                                    input_tag='Reservations', check_tag='NextToken', **kwargs)
 
-    def get_volumes(self):
+    def get_volumes(self, **kwargs):
         """
         This method returns all volumes in the region
         @return:
         """
         return self.utils.get_details_resource_list(func_name=self.ec2_client.describe_volumes, input_tag='Volumes',
-                                                    check_tag='NextToken')
+                                                    check_tag='NextToken', **kwargs)
 
     def get_images(self):
         """
@@ -493,7 +495,7 @@ class EC2Operations:
                              'InstanceType': instance.get('InstanceType'),
                              'LaunchTime': instance.get('LaunchTime').strftime('%Y/%m/%d %H:%M:%S'),
                              'Region': region.get('RegionName'),
-                             'Account': os.environ.get('account', '').upper(),
+                             'Account': self.__environment_variables_dict.get('account', '').upper(),
                              'State': instance.get('State')['Name']
                              }
                 user = self.get_tag(name='User', tags=instance.get('Tags'))
@@ -502,3 +504,15 @@ class EC2Operations:
                 else:
                     users_list[user] = [user_data]
         return users_list
+
+    def get_tag_value_from_tags(self, tags: list, tag_name: str) -> str:
+        """
+        This method return the tag value inputted by tag_name
+        """
+        if tags:
+            for tag in tags:
+                key = tag.get('Key').lower().replace("_", '').replace("-", '')
+                if key == tag_name.lower():
+                    return tag.get('Value')
+        return ''
+
